import { Hono } from 'hono';
import { CORE_VERSION } from '@tidyindex/core';

export interface Env {
  // DATABASE_URL: string;
  // KEY_CACHE: KVNamespace;
  // ACCOUNT_METER: DurableObjectNamespace;
}

const app = new Hono<{ Bindings: Env }>();

app.get('/', (c) =>
  c.json({
    name: 'tidyindex-api',
    version: '0',
    core: CORE_VERSION
  })
);

export default app;
