<footer class="app-footer">
  <div class="container app-footer-inner">
    <p class="app-footer-line">
      Need something &mdash; email us at
      <a href="mailto:contact@tidyindex.com">contact@tidyindex.com</a>
    </p>
  </div>
</footer>
