<script lang="ts">
  import { toasts } from '$lib/stores/toasts';
</script>

<div class="toast-container" aria-live="polite" aria-atomic="true">
  {#each $toasts as t (t.id)}
    <div class="toast toast-{t.kind}">
      <span class="toast-dot"></span>
      <span>{t.message}</span>
    </div>
  {/each}
</div>
