<header class="site-header">
  <div class="container header-inner">
    <a href="{{ "/" | relURL }}" class="brand" aria-label="Tidy Index home">
      <span class="brand-mark" aria-hidden="true">
        <svg viewBox="0 0 32 32" fill="none" xmlns="http://www.w3.org/2000/svg">
          <rect x="4" y="6" width="24" height="3" rx="1.5" fill="currentColor"/>
          <rect x="4" y="14" width="18" height="3" rx="1.5" fill="currentColor" opacity="0.7"/>
          <rect x="4" y="22" width="12" height="3" rx="1.5" fill="currentColor" opacity="0.4"/>
        </svg>
      </span>
      <span class="brand-name">Tidy&nbsp;Index</span>
    </a>
    <div class="header-meta">
      <span class="header-status"><span class="status-dot" aria-hidden="true"></span> Private beta</span>
      <a href="{{ partial "dashboard-url.html" . }}" class="header-cta">API&nbsp;Key &rarr;</a>
    </div>
  </div>
</header>
