// See https://kit.svelte.dev/docs/types#app

import type { Account } from '$lib/server/db';

declare global {
  namespace App {
    interface Locals {
      account: Account | null;
    }
    // interface PageData {}
    // interface PageState {}
    // interface Platform {}
  }
}

export {};
